@@ -5,6 +5,6 @@ import Pyro.core
 
 
 s = Pyro.core.getProxyForURI("PYROLOC://localhost:7766/rpc")
-dbg_path = s.debug_func('next_prime')
+dbg_path = s.debug_func('next_prime', match_criteria={'p':79})
 
-termsock.TermSock(dbg_path).mainloop()
+termsock.terminal(dbg_path)
